@@ -57,7 +57,7 @@ $YAHOO_CURRENCY_URL = "http://finance.yahoo.com/d/quotes.csv?e=.csv&f=l1&s=";
                 currency_lookup/;
 @EXPORT_TAGS = ( all => [@EXPORT_OK]);
 
-$VERSION = '1.18';
+$VERSION = '1.19';
 
 $USE_EXPERIMENTAL_UA = 0;
 
@@ -176,7 +176,7 @@ sub new {
     @modules = qw/AEX AIAHK ASEGR ASX BMONesbittBurns BSERO Bourso Cdnfundlibrary
             Currencies Deka DWS FTPortfolios Fidelity FinanceCanada Fool HU
             GoldMoney HEX
-            IndiaMutual LeRevenu ManInvestments Morningstar NZX Platinum SEB
+            IndiaMutual LeRevenu ManInvestments Morningstar MorningstarJP MtGox NZX Platinum SEB
             SIXfunds SIXshares StockHouseCanada TSP TSX Tdefunds Tdwaterhouse Tiaacref Troweprice
             Trustnet Union USFedBonds VWD ZA Cominvest Finanzpartner
             Yahoo::Asia Yahoo::Australia Yahoo::Brasil Yahoo::Europe Yahoo::NZ
@@ -647,29 +647,6 @@ sub parse_csv
        return @new;      # list of values that were comma-separated
 }
 
-# =======================================================================
-# parse_csv_semicolon (public object method)
-#
-# Grabbed from the Perl Cookbook. Parsing csv isn't as simple as you thought!
-#
-sub parse_csv_semicolon
-{
-    shift if (ref $_[0]); # Shift off the object if we have one.
-    my $text = shift;      # record containing comma-separated values
-    my @new  = ();
-
-    push(@new, $+) while $text =~ m{
-        # the first part groups the phrase inside the quotes.
-        # see explanation of this pattern in MRE
-        "([^\"\\]*(?:\\.[^\"\\]*)*)";?
-           |  ([^;]+);?
-           | ;
-       }gx;
-       push(@new, undef) if substr($text, -1,1) eq ';';
-
-       return @new;      # list of values that were comma-separated
-}
-
 # =======================================================================
 # store_date (public object method)
 #
