@@ -40,9 +40,9 @@ use HTML::TableExtract;
 
 use vars qw/$ASX_URL $VERSION/;
 
-$VERSION = '1.16';
+$VERSION = '1.19';
 
-$ASX_URL = 'http://www.asx.com.au/asx/markets/PriceResults.jsp?method=get&template=F1001&ASXCodes=';
+$ASX_URL = 'http://www.asx.com.au/asx/markets/priceLookup.do?by=asxCodes&asxCodes=';
 
 sub methods {return (australia => \&asx,asx => \&asx)}
 
@@ -105,6 +105,9 @@ sub asx {
 		# Also delete high bit characters.
 		$stock =~ tr/* \200-\377//d;
 
+		# Delete any whitespace characters
+		$stock =~ s/\s//g;
+
 		$info{$stock,'symbol'} = $stock;
 
 		foreach my $label (qw/last p_change bid offer open
@@ -112,10 +115,10 @@ sub asx {
 			$info{$stock,$label} = shift(@$row);
 
 			# Again, get rid of nasty high-bit characters.
-			$info{$stock,$label} =~ tr/ \200-\377//d 
+			$info{$stock,$label} =~ tr/ \200-\377//d
 				unless ($label eq "name");
 		}
-		
+
 		# If that stock does not exist, it will have a empty
 		# string for all the fields.  The "last" price should
 		# always be defined (even if zero), if we see an empty
