@@ -21,7 +21,7 @@ use base 'Exporter';
 use vars qw/@EXPORT_OK $VERSION $YAHOO_CURRENCY_CONV_URL/;
 
 @EXPORT_OK = qw( known_currencies fetch_live_currencies );
-$VERSION = '1.16';
+$VERSION = '1.19';
 
 use HTTP::Request::Common;
 use LWP::UserAgent;
@@ -78,7 +78,6 @@ my %currencies = ( ALL => { name => qq{Albanian Lek} }
                  , CRC => { name => qq{Costa Rica Colon} }
                  , HRK => { name => qq{Croatian Kuna} }
                  , CUP => { name => qq{Cuban Peso} }
-                 , CYP => { name => qq{Cyprus Pound} }
                  , CZK => { name => qq{Czech Koruna} }
                  , DKK => { name => qq{Danish Krone} }
                  , DJF => { name => qq{Dijibouti Franc} }
@@ -115,7 +114,7 @@ my %currencies = ( ALL => { name => qq{Albanian Lek} }
                  , JOD => { name => qq{Jordanian Dinar} }
                  , KZT => { name => qq{Kazakhstan Tenge} }
                  , KES => { name => qq{Kenyan Shilling} }
-                 , KRW => { name => qq{Korean Won} }
+                 , KRW => { name => qq{South Korean Won} }
                  , KWD => { name => qq{Kuwaiti Dinar} }
                  , LAK => { name => qq{Lao Kip} }
                  , LVL => { name => qq{Latvian Lat} }
@@ -140,7 +139,7 @@ my %currencies = ( ALL => { name => qq{Albanian Lek} }
                  , NAD => { name => qq{Namibian Dollar} }
                  , NPR => { name => qq{Nepalese Rupee} }
                  , ANG => { name => qq{Neth Antilles Guilder} }
-                 , TRY => { name => qq{New Turkish Lira} }
+                 , TRY => { name => qq{Turkish Lira} }
                  , NZD => { name => qq{New Zealand Dollar} }
                  , NIO => { name => qq{Nicaragua Cordoba} }
                  , NGN => { name => qq{Nigerian Naira} }
@@ -175,7 +174,6 @@ my %currencies = ( ALL => { name => qq{Albanian Lek} }
                  , ZAR => { name => qq{South African Rand} }
                  , LKR => { name => qq{Sri Lanka Rupee} }
                  , SHP => { name => qq{St Helena Pound} }
-                 , SDD => { name => qq{Sudanese Dinar} }
                  , SZL => { name => qq{Swaziland Lilageni} }
                  , SEK => { name => qq{Swedish Krona} }
                  , CHF => { name => qq{Swiss Franc} }
@@ -183,20 +181,21 @@ my %currencies = ( ALL => { name => qq{Albanian Lek} }
                  , TWD => { name => qq{Taiwan Dollar} }
                  , TZS => { name => qq{Tanzanian Shilling} }
                  , THB => { name => qq{Thai Baht} }
-                 , TOP => { name => qq{Tonga Pa'anga} }
-                 , TTD => { name => qq{Trinidad&Tobago Dollar} }
+                 , TOP => { name => qq{Tonga Pa'ang} }
+                 , TTD => { name => qq{Trinidad & Tobago Dollar} }
                  , TND => { name => qq{Tunisian Dinar} }
-                 , USD => { name => qq{U.S. Dollar} }
+                 , USD => { name => qq{United States Dollar} }
                  , AED => { name => qq{UAE Dirham} }
                  , UGX => { name => qq{Ugandan Shilling} }
                  , UAH => { name => qq{Ukraine Hryvnia} }
                  , UYU => { name => qq{Uruguayan New Peso} }
                  , VUV => { name => qq{Vanuatu Vatu} }
-                 , VEB => { name => qq{Venezuelan Bolivar} }
+                 , VEF => { name => qq{Venezuelan Bolivar Fuerte}}
                  , VND => { name => qq{Vietnam Dong} }
                  , YER => { name => qq{Yemen Riyal} }
                  , ZMK => { name => qq{Zambian Kwacha} }
-                 , ZWD => { name => qq{Zimbabwe Dollar} }
+                 , ZWD => { name => qq{Zimbabwe dollar} }
+                 , SDG => { name => qq{Sudanese Pound} }
                  );
 
 # =======================================================================
@@ -226,7 +225,7 @@ sub fetch_live_currencies {
   # Avoid the "Parsing of undecoded UTF-8 will give garbage when decoding
   # entities" warning by forcing utf mode and encoding to utf8
   $p->utf8_mode(1);
-  $p->parse( Encode::encode_utf8($data) ); 
+  $p->parse( Encode::encode_utf8($data) );
 
   return _live_currencies();
 }
@@ -241,16 +240,16 @@ sub fetch_live_currencies {
   my $in_currency_option = 0;
   my $currency_text = '';
   my $currency_code = '';
-  
+
   # _start_handler (private function)
   #
   # This is a HTML::Parser start tag handler
   sub _start_handler {
     my ($tagname, $attr) = @_;
- 
+
     if ( lc $tagname eq 'select'
          &&
-         exists $attr->{name} && lc $attr->{name} eq 'from'
+         exists $attr->{name} && lc $attr->{name} eq 'currency-1'
        ) {
       # Reset status
       %live_currencies = ();
@@ -267,7 +266,7 @@ sub fetch_live_currencies {
       $currency_text = '';
     }
   }
-  
+
   # _end_handler (private function)
   #
   # This is a HTML::Parser end tag handler
@@ -337,7 +336,7 @@ Finance::Quote::Currencies - List of currencies from Yahoo Finance
 This module provides a list of known currencies from Yahoo Currency Converter.
 
 The converter website includes a list of known currencies - this module includes
-a stored list 
+a stored list
 
 =head1 LAST EXTRACT
 
