@@ -14,14 +14,18 @@ use HTTP::Request::Common;
 use HTTP::Status;
 use HTML::TableExtract;
 
-$VERSION = '1.16';
+$VERSION = '1.19';
 
 # URLs of where to obtain information.
 
 #$AMFI_MAIN_URL = ("http://localhost/");
-$AMFI_MAIN_URL = ("http://amfiindia.com/");
-$AMFI_URL = ("${AMFI_MAIN_URL}downloadnavopen.asp");
-$AMFI_NAV_LIST = "/tmp/amfinavlist.txt";
+$AMFI_MAIN_URL = ("http://www.amfiindia.com/");
+$AMFI_URL = ("${AMFI_MAIN_URL}NavReport.aspx?type=0");
+#$AMFI_URL = ("${AMFI_MAIN_URL}spages/NAV0.txt"); #This page seems to do the job also. Keep for reference
+
+# amfinavlist.txt is a cache-file. keep it until updated on the website since this is a 1meg file.
+my $cachedir = $ENV{TMPDIR} // $ENV{TEMP} // '/tmp/';
+$AMFI_NAV_LIST = $cachedir."amfinavlist.txt";
 
 sub methods { return (indiamutual => \&amfiindia,
 		      amfiindia => \&amfiindia); }
@@ -38,8 +42,8 @@ sub methods { return (indiamutual => \&amfiindia,
 sub amfiindia   {
     my $quoter = shift;
     my @symbols = @_;
-    
-    # Make sure symbols are requested  
+
+    # Make sure symbols are requested
     ##CAN exit more gracefully - add later##
 
     return unless @symbols;
@@ -85,17 +89,17 @@ sub amfiindia   {
 
 	my $data = $allquotes{$symbol};
 	if ($data) {
-	    $fundquote{$symbol, "name"} = $data->[0];
-	    $fundquote{$symbol, "nav"} = $data->[1];
-	    $fundquote{$symbol, "rprice"} = $data->[2];
-	    $fundquote{$symbol, "sprice"} = $data->[3];
-	    $quoter->store_date(\%fundquote, $symbol, {eurodate => $data->[4]});
-	    $fundquote{$symbol, "success"} = 1;
+            $fundquote{$symbol, "name"} = $data->[4];
+            $fundquote{$symbol, "nav"} = $data->[5];
+            $fundquote{$symbol, "rprice"} = $data->[6];
+            $fundquote{$symbol, "sprice"} = $data->[7];
+            $quoter->store_date(\%fundquote, $symbol, {eurodate => $data->[8]});
+            $fundquote{$symbol, "success"} = 1;
 	} else {
 	    $fundquote{$symbol, "success"} = 0;
 	    $fundquote{$symbol, "errormsg"} = "Fund not found";
 	}
-    } 
+    }
 
     return wantarray ? %fundquote : \%fundquote;
 }
@@ -121,7 +125,7 @@ module only.
 
 =head1 DESCRIPTION
 
-This module obtains information about Indian Mutual Fund prices from the 
+This module obtains information about Indian Mutual Fund prices from the
 Association of Mutual Funds India website amfiindia.com.
 The information source "indiamutual" can be used
 if the source of prices is irrelevant, and "amfiindia" if you
@@ -132,7 +136,7 @@ specifically want to use information downloaded from amfiindia.com.
 In India a mutual fund does not have a unique global symbol identifier.
 
 This module uses an id that represents the mutual fund on an id used by
-amfiindia.com.  You can the fund is from the AMFI web site 
+amfiindia.com.  You can the fund is from the AMFI web site
 http://amfiindia.com/downloadnavopen.asp.
 
 =head1 LABELS RETURNED
@@ -144,11 +148,11 @@ label will be a url location for the NAV list table for all funds.
 
 =head1 NOTES
 
-amfiindia.com provides a link to download a text file containing all the 
-NAVs. This file is mirrored in a local file /tmp/amfinavlist.txt. The local 
-mirror serves only as a cache and can be safely removed. 
+amfiindia.com provides a link to download a text file containing all the
+NAVs. This file is mirrored in a local file /tmp/amfinavlist.txt. The local
+mirror serves only as a cache and can be safely removed.
 
-Currently NAVs of Open-Ended funds are supported. 
+Currently NAVs of Open-Ended funds are supported.
 
 =head1 SEE ALSO
 
@@ -157,4 +161,3 @@ AMFI india website - http://amfiindia.com/
 Finance::Quote
 
 =cut
-
