@@ -3,7 +3,7 @@
 #    Copyright (C) 1998, Dj Padzensky <djpadz@padz.net>
 #    Copyright (C) 1998, 1999 Linas Vepstas <linas@linas.org>
 #    Copyright (C) 2000, Yannick LE NY <y-le-ny@ifrance.com>
-#    Copyright (C) 2000, Paul Fenwick <pjf@Acpan.org>
+#    Copyright (C) 2000, Paul Fenwick <pjf@cpan.org>
 #    Copyright (C) 2000, Brent Neal <brentn@users.sourceforge.net>
 #    Copyright (C) 2000, Volker Stuerzl <volker.stuerzl@gmx.de>
 #    Copyright (C) 2003,2005,2006 Jrg Sommer <joerg@alea.gnuu.de>
@@ -44,10 +44,10 @@ use HTML::TreeBuilder;
 
 use vars qw/$VERSION/;
 
-$VERSION = '1.16';
+$VERSION = '1.19';
 
 sub methods { return (vwd => \&vwd); }
-sub labels { return (vwd => [qw/currency date isodate 
+sub labels { return (vwd => [qw/currency date isodate
             name price last symbol time/]); }
 
 # =======================================================================
@@ -123,7 +123,10 @@ sub vwd
       next if not $content;
 
       # <h1> contains price, time, name, and symbol
-      my $head = $content->find("h1");
+      my $head = $content->look_down(
+	 "_tag", "div",
+	 "class", "wpHeadline"
+      );
       next if not $head;
 
       my $wpkurs = $head->look_down(
@@ -148,21 +151,24 @@ sub vwd
          $_->delete;
       }
 
-      if ($head->as_trimmed_text =~ /^(.*) \((.+)\)$/) {
-         $info{$fund, "name"} = $1;
-         $info{$fund, "symbol"} = $2;
+      my $wpsymbol = $content->look_down(
+         "_tag", "ul",
+         "class", "wpInfo"
+      );
+      if ($wpsymbol) {
+         my @li = $wpsymbol->find("li");
+         if ($li[4]->as_text =~ /WKN:(\w+)/) {
+            $info{$fund, "symbol"} = $1;
+         }
       }
 
       # <ul> contains currency as 3rd <li>
       my $wpinfo = $content->look_down(
-         "_tag", "ul",
-         "class", "wpInfo"
+         "_tag", "span",
+         "class", "whrg"
       );
       if ($wpinfo) {
-         my @li = $wpinfo->find("li");
-         if ($li[2]->as_text =~ /Whrung:(\w+)/) {
-            $info{$fund, "currency"} = substr($1, 0, 3);
-         }
+         $info{$fund, "currency"} = substr($wpinfo->as_text, 0, 3);
       }
 
       # fund ok
@@ -212,5 +218,3 @@ currency date isodate name price last symbol time.
 vwd Vereinigte Wirtschaftsdienste GmbH, http://www.vwd.de/
 
 =cut
-
- 	  	 
