@@ -35,11 +35,11 @@ use Finance::Quote::Yahoo::Base qw/yahoo_request base_yahoo_labels/;
 
 use vars qw/$VERSION $YAHOO_AUSTRALIA_URL/;
 
-$VERSION = '1.16';
+$VERSION = '1.19';
 
 # URLs of where to obtain information.
 
-$YAHOO_AUSTRALIA_URL = ("http://au.finance.yahoo.com/d/quotes.csv");
+$YAHOO_AUSTRALIA_URL = ("http://download.finance.yahoo.com/d/quotes.csv");
 
 sub methods {return (australia       => \&yahoo_australia,
 		     yahoo_australia => \&yahoo_australia)};
