@@ -44,7 +44,7 @@ use vars qw/$VERSION @FIELDS @FIELD_ENCODING $MAX_REQUEST_SIZE @ISA
 @EXPORT = qw//;
 @EXPORT_OK = qw/yahoo_request base_yahoo_labels/;
 
-$VERSION = '1.16';
+$VERSION = '1.19';
 
 # This is the maximum number of stocks we'll batch into one operation.
 # If this gets too big (>50 or thereabouts) things will break because
@@ -144,7 +144,7 @@ my %currency_tags = (
 # This function expects a Finance::Quote object, a base URL to use,
 # a refernece to a list of symbols to lookup.  If a fourth argument is
 # used then it will act as a suffix that needs to be appended to the stocks
-# in order to obtain the correct information.  This function relies upon 
+# in order to obtain the correct information.  This function relies upon
 # the fact that the various Yahoo's all work the same way.
 
 sub yahoo_request {
@@ -156,8 +156,6 @@ sub yahoo_request {
 
 	# The suffix is used to specify particular markets.
 	my $suffix = shift || "";
-	
-	my $uses_semicolon = shift || 0;
 
 	my %info;
 	my $ua = $quoter->user_agent;
@@ -175,6 +173,7 @@ sub yahoo_request {
 
 		my $url = $base_url . join("$suffix+",@symbols);
 		chop $url;	# Chop off the final +
+                print "DEBUG - GET: $url\n" if $ENV{"FQ_DEBUG"};
 		my $response = $ua->request(GET $url);
 		return unless $response->is_success;
 
@@ -183,11 +182,7 @@ sub yahoo_request {
 
 		foreach (split('\015?\012',$response->content)) {
 			my @q;
-			if ($uses_semicolon) {
-				@q = $quoter->parse_csv_semicolon($_);
-			} else {
-				@q = $quoter->parse_csv($_);
-			}
+                        @q = $quoter->parse_csv($_);
 			my $symbol = $q[0];
 			my ($exchange) = $symbol =~ m/\.([A-Z]+)/;
 
@@ -250,10 +245,43 @@ sub yahoo_request {
                           $info{$symbol,"time"} = $quoter->isoTime($info{$symbol,"time"});
                         }
 
+                        # "cap" from Yahoo::USA sometimes has "B" for
+                        # billions suffix, eg. from "F" Ford -- expand that
+                        # to a plain number for ease of use
+                        if (defined($info{$symbol,"cap"})) {
+                          $info{$symbol,"cap"}
+                            = $quoter->B_to_billions ($info{$symbol,"cap"});
+                        }
+
+      # Convert prices (when needed). E.G. Some London sources
+      # return in pence. Yahoo denotes this with GBP vs GBp
+      # We'd like them to return in pounds (divide by 100).
+      if (defined($exchange)) {
+        if ((($exchange eq "L") &&
+             (($info{$symbol,"currency"} eq "GBp") ||
+              #Assume GBX also quoted in pence; if not remove next line
+              ($info{$symbol,"currency"} eq "GBX"))) ||
+            ($exchange eq "TA")) {
+          foreach my $field ($quoter->default_currency_fields) {
+            next unless ($info{$symbol,$field});
+            $info{$symbol,$field} =
+              $quoter->scale_field($info{$symbol,$field},0.01);
+          }
+        } ;
+        if (($exchange eq "L") && defined($info{$symbol,"year_range"})) {         # if a year range is returned for exchange=L
+          if ($info{$symbol,"year_range"}=~ m/([\d\.]+)\s*-\s*([\d\.]+)/) {       # take year low and high
+            my ($year_low,$year_high) = ($1,$2) ;
+            if ($info{$symbol,"close"} <= $year_low) {                            # sometimes year_range was expressed in .01 GBp
+              $info{$symbol,"year_range"} = ($year_low/100)." - ".($year_high/100) ;
+            }
+          }
+        }
+        # Other exchanges here as needed.
+      }
+
 			if (defined($info{$symbol,"currency"})) {
-			  # Convert the currency to be all uppercase for
-			  # backward compatability.  Needed because Yahoo
-			  # returns GBP as GBp.  There may be others.
+        # Having converted London prices to GBP above we
+        # make upper-case and turn GBX to GBP.
 			  $info{$symbol,"currency"} =~ tr/a-z/A-Z/;
                           # yahoo started to return GBX instead of GBP
                           # somewhere arround 9 oct 2008.
@@ -274,20 +302,6 @@ sub yahoo_request {
 			  $info{$symbol,"currency_set_by_fq"} = 1;
 			}
 
-			# Convert prices (when needed). E.G. London sources
-			# return in pence. We'd like them to return in pounds
-			# (divide by 100).
-			if (defined($exchange)) {
-			  if (($exchange eq "L"  && $info{$symbol,"currency"} eq "GBP") ||
-			      ($exchange eq "TA")) {
-			    foreach my $field ($quoter->default_currency_fields) {
-			      next unless ($info{$symbol,$field});
-			      $info{$symbol,$field} =
-				$quoter->scale_field($info{$symbol,$field},0.01);
-			    }
-			  }
-			  # Other exchanges here as needed.
-			}
 
 		} # End of processing each stock line.
 	} # End of lookup loop.
@@ -314,6 +328,7 @@ sub yahoo_request {
 	return \%info;
 }
 
+
 1;
 
 =head1 NAME
