@@ -36,11 +36,11 @@ use Finance::Quote::Yahoo::Base qw/yahoo_request base_yahoo_labels/;
 
 use vars qw($VERSION $YAHOO_EUROPE_URL);
 
-$VERSION = '1.15';
+$VERSION = '1.19';
 
 # URLs of where to obtain information.
 
-$YAHOO_EUROPE_URL = ("http://uk.finance.yahoo.com/d/quotes.csv");
+$YAHOO_EUROPE_URL = ("http://download.finance.yahoo.com/d/quotes.csv");
 
 # Yahoo Europe switched date and time. sending t1d1 or d1t1
 # returns the same : Time followed by date. This is a short
@@ -50,9 +50,10 @@ $YAHOO_EUROPE_URL = ("http://uk.finance.yahoo.com/d/quotes.csv");
 # Another solution might be to change Base.pm FIELDS labels to this
 # string + div_date and ex_div. Code would be nicier, but this will
 # need more testing for other yahoo modules and can be done later.
-our @YH_EUROPE_FIELDS = qw/symbol name last time date net p_change volume bid ask
+our @YH_EUROPE_FIELDS = qw/symbol name last net p_change volume bid ask
                            close open day_range year_range eps pe div div_yield
-                           cap avg_vol currency/;
+                           cap avg_vol currency time date ex_div div_date/;
+our @YH_FIELD_ENCODING = qw/s n l1 c1 p2 v b a p o m w e r d y j1 a2 c4 t1 d1 q r1/;
 
 sub methods {return (europe => \&yahoo_europe,yahoo_europe => \&yahoo_europe)};
 
@@ -73,6 +74,7 @@ sub yahoo_europe
         # localise the Base.FIELDS array. Perl restores the array at
         # the end of this sub.
         local @Finance::Quote::Yahoo::Base::FIELDS = @YH_EUROPE_FIELDS ;
+        local @Finance::Quote::Yahoo::Base::FIELD_ENCODING = @YH_FIELD_ENCODING ;
 
 	# This does all the hard work.
 	my %info = yahoo_request($quoter,$YAHOO_EUROPE_URL,\@symbols);
@@ -97,8 +99,8 @@ Finance::Quote::Yahoo::Europe - Fetch quotes from Yahoo Europe
     use Finance::Quote;
     $q = Finance::Quote->new;
 
-    %info = $q->fetch("europe","12150.PA"); # Failover to other methods ok.
-    %info = $q->fetch("yahoo_europe","12150.PA"); # Use this module only.
+    %info = $q->fetch("europe","UG.PA"); # Failover to other methods ok.
+    %info = $q->fetch("yahoo_europe","UG.PA"); # Use this module only.
 
 =head1 DESCRIPTION
 
@@ -140,6 +142,11 @@ Finance::Quote->new().
 Information obtained by this module may be covered by Yahoo's terms
 and conditions.  See http://finance.uk.yahoo.com/ for more details.
 
+=head1 SPECIFIC NOTES ON CERTAIN SYMBOLS
+
+Starting in November 2010, the Yahoo site didn't respond to ^DJI symbol
+retrieval. Use ^DJI.US instead.
+
 =head1 LABELS RETURNED
 
 This module returns all the standard labels (where available) provided
