@@ -37,11 +37,11 @@ use Finance::Quote::Yahoo::Base qw/yahoo_request base_yahoo_labels/;
 
 use vars qw/$VERSION $YAHOO_URL/;
 
-$VERSION = '1.16';
+$VERSION = '1.19';
 
 # URLs of where to obtain information.
 
-$YAHOO_URL = ("http://finance.yahoo.com/d");
+$YAHOO_URL = ("http://download.finance.yahoo.com/d/quotes.csv");
 
 sub methods {return (canada   => \&yahoo,
                      usa      => \&yahoo,
